@@ -1054,6 +1054,9 @@ contains
     !   Computes
     !      -E(dl2/dmu2), -E(dl2/dmUdnu) and -E(dl2/dnu2)
     !   for Matsuoka regression models.
+		!
+		! Last update: February/2026.
+		!  - corrected the formula
     !**********************************************************************
     implicit none
     class(argsDist), intent(inout) :: argsD
@@ -1070,7 +1073,7 @@ contains
     do t = (m + 1), n
        m2 = mu(t)**2
        m3 = m2**(1.d0 / 3.d0)
-       E(t, 1) = (4.d0 - 10.d0 * m3) / (3.d0 * (1 - m3)**2 * m2)
+       E(t, 1) = 2.0d0 / (3.d0 * (1 - m3)**2 * m2)
     end do
     return
   end subroutine Ed2llk_matsu
